<?php

////////////////////////////////////////////////////////////////////////
/**
 *	A TemplateExecuter takes a template name, and a page's PageParts and executes (displays) them  
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////
class TemplateExecuter 
{ 
	public $templateName;
	public $pageParts;

	private $context;

	/**
	 * TemplateExecuter Constructor. DOES NOT EXECUTE THE TEMPLATE!!!
	 * 
	 * @param Context @_context the current Context
	 * @param string @_templateName The name of the template to execute
	 * @param array $_pageParts an array of PagePart objects to use
	 */
	public function TemplateExecuter($_context, $_templateName, $_pageParts)
	{
		$this->context = $_context;
		$this->templateName = $_templateName;
		$this->pageParts = $_pageParts;
		
	}

	/**
	 * find a pagepart with the matching name, and execute it. This function is called by the template
	 * 
	 * @param string $type the type of the page part
	 * @param int $index a unique integer for this page part to execute
	 */
	public function executePagePart($type,$index) 
	{
		$name = $type.$index;
		for($i = 0; $i < count($this->pageParts); $i++)
		{
			$p = $this->pageParts[$i];
			if (strcasecmp($p->name, $name) == 0) 
			{ 
				$p->execute();
				return true;
			}	
		} // for

		// let's create the page part that doesn't exist already
		$pp = new PagePart($this->context->currentPage->GUID, $type, $name, CreateGUID(), -1,$this->context);
		// echo("page part \"".$name."\" (".$type.") was not found. Creating it... <br>");
		// debug($pp);
		$r = $pp->SaveToDatabase();

		return $r;
	}

	/**
	 * execute (display) a named control
	 * 
	 * @param string $name the name of the control to execute
	 */
	public function executeControl($name) 
	{

		$fn = "controls/".$name.".inc";
		if(file_exists($fn)) {
			include($fn);	
		} // if file exists				
	}

	/**
	 * execute (displays) the template
	 */
	public function execute() {
		
		$fn = "templates/".$this->templateName.".inc";
		if(file_exists($fn)) {
			include($fn);	
		} // if file exists				
	}

} // class

?>