<?php

////////////////////////////////////////////////////////////////////////
/**
 *	Attachment Object
 *
 *	An attachment is similar to a page (in that it has a friendly URL), but it
 * 	differs from a page in that 
 * 	- an attachment can not have any children
 * 	- an attachment must belong to a Page
 *  - there must be some file associated with the Attachment that will be displayed when the attachment is accessed 
 * 	
 * 	Attachments are useful for attaching Word, Excel, PDF, GIF, JPEG, ZIP, MP3 and any other type of data file
 * 	to a Page. 
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 
 * @todo The Attachment Object is not complete (Oct. 2005), and has not been integrated with the Context object
 *
 **/
////////////////////////////////////////////////////////////////////////
class Attachment 
{ 

	/**
	 * @var Context the current context
	 */
	public $context;
	public $attachment_id;
	public $parentPageID; // integer
	public $name; // the url name
	public $displayname; // the human readable title
	public $type; // the type of the attachment
	public $attributes; // array of attributes
	public $sortOrdinal; // integer
	public $deleted; // date-stamp

	public function Attachment($_context)
	{
		$this->context = $_context;
		$this->attributes = array();
		$this->parentPageID = -1;
		$this->attachment_id = -1;

	} // constructor

	/**
	 * execute (show) this attachment based on the attributes
	 */
	public function Execute() 
	{
		debug("Attachment->Execute<p>");
		if($this->type != '') 
		{
			$type_lc = strtolower($this->type);
			$inc_fn = "core/attachments/attachment.".$type_lc.".inc";
			if(file_exists($inc_fn)) 
			{
				include_once($inc_fn);				
			}		
		}
	} // Execute

	public function InitFromDatabase($_parentPageID, $_name )
	{
		$this->parentPageID = $_parentPageID;
		
		$_name = $this->context->db->getGoodDBURLName($_name);
		$parentQuery = "and parentPage = ".$_parentPageID."";
		if($_parentPageID == "" || $_parentPageID === "-1" || $_parentPageID ===-1 || $_parentPageID == 'null' || $_parentPageID == "NULL") 
		{
			$parentQuery = "and isNull(ParentPage)";
		}
		$sql = "SELECT `attachmentId`, `parentPage`, `Name`, `DisplayName`, `type`, `attributes`, `SortOrdinal` FROM `Attachments` where (now() < Deleted or IsNull(Deleted)) ".$parentQuery." and (Name = '".$_name."')"; 

		// do the query
		$result = $this->context->db->query($sql);
		if($this->context->db->numRows() > 0) 
		{
			$row = $this->context->db->getNext(); 
			
			$this->loadFromDBRow($row);
			$this->InitPageParts();
			return true;

		}
		else
		{
			return false;
		}
	} // InitFromDatabase

	public function InitFromDatabaseByID($_attachmentID )
	{
		$sql = "SELECT `attachmentId`, `parentPage`, `Name`, `DisplayName`, `type`, `attributes`, `SortOrdinal` FROM `Attachments` where (now() < Deleted or IsNull(Deleted)) and (attachmentId = '".$_attachmentID."')"; 

		$result = $this->context->db->query($sql);
		if($this->context->db->numRows() > 0 ) 
		{
			$row = $this->context->db->getNext();
			
			$this->loadFromDBRow($row);

			return true;

		}
		else
		{
			return false;
		}
	}


	public function loadFromDBRow($row) 
	{
		$this->attachment_id = $row["attachmentId"];
		$this->parentPageID = $row["parentPage"];

		$this->name = $row["Name"];
		$this->displayname = $row["DisplayName"];
		$this->sortordinal = $row["SortOrdinal"];

		$this->type = trim($row["type"]);
		
		$this->attributes = unserialize($row["attributes"]);

	} // loadFromDBRow

	public function URL()
	{
			$url = $this->name."";			


		$parentPage = $this->parentPage();

		while($parentPage != NULL) 
		{
			$url = $parentPage->name."/".$url;

			$parentPage = $parentPage->parentPage();				
		} // while

		if($url == "") 
		{
			$url = "/";
			
		}

		return $url;		
		
	} // URL

	public function parentPage() 
	{
		$ret = NULL;
		if($this->parentPageID != -1 && $this->parentPageID != "") 
		{
			# echo('parentpage '.$this->parentPageID);
			$ret = $this->context->getPageByPageID($this->parentPageID);	
			# echo('xx');
		}
		return $ret;
	} // parentPage

	// create a new entry, or update an existing one if it exists
	public function SaveToDatabase() 
	{
	
		$_guid = $this->attachment_id;

		$sql = "SELECT `attachmentId` FROM `Attachments` where (now() < Deleted or IsNull(Deleted)) and (attachmentId = '".$_guid."')"; 

		/* Connecting, selecting database */ 
		$link = mysql_connect("localhost", "phpwebsite", "phpwebsite") or die("Could not connect : " . mysql_error()); 
 
		mysql_select_db("myphpwebsite") or die("Could not select database myphpwebsite"); 

		$return = false;
		/* Performing SQL query */ 
		$result = mysql_query($sql) or die("Page Query failed : " . mysql_error()); 
		if($result && mysql_num_rows($result) > 0  )
		{
			// ----------------
			// -- the attachment exists in the database. let's update it
			$row = mysql_fetch_assoc($result);
			$return = $this->UpdateDatabase($link, $row["attachmentId"]);
		}
		else
		{
			// ----------------
			// -- attachment does not exist. let's create it
			$return = $this->InsertIntoDatabase($link);
		}

		mysql_close($link);
		return $return;

		
	} // SaveToDatabase

	private function UpdateDatabase($link, $_attachmentID) 
	{
		
		$attr = serialize($this->attributes);
		$sql = "UPDATE Attachments SET ParentPage = ".$this->parentPageID.", Name = '".$this->name."', DisplayName = '".$this->displayname."', SortOrdinal = '".$this->sortordinal."', attributes = '".$attr."', type = '".$this->type."' where attachmentId = '".$_attachmentID."';";

		mysql_query($sql) or die("Invalid attachment update: " . mysql_error()." <br> ".$sql);
		return (mysql_affected_rows() == 1);
		
	} // UpdateDatabase

	private function InsertIntoDatabase($link) 
	{

		$attr = serialize($this->attributes);
		$sql = "INSERT INTO Attachments (ParentPage, Name, DisplayName, SortOrdinal, attributes, type) VALUES(".$this->parentPageID.", '".$this->name."', '".$this->displayname."','".$this->sortOrdinal."', '".$attr."','".$this->type."');";

		mysql_query($sql) or die("Invalid attachment insert: " . mysql_error()." <br> ".$sql);

		$id = mysql_insert_id();
		if($id == 0) { $this->GUID = -1; return false;}
		else 
		{
			 $this->GUID = $id;
			 return true;
		}
		
	} // InsertIntoDatabase

} // class Attachment