<?php
require_once $GLOBALS['root_core_path'].'/anyDB/anyDB.php'; 

////////////////////////////////////////////////////////////////////////
/**
 *	The database access class.
 *	This class essentially wraps the "AnyDB" class by Lennart Groetzbach  
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////
class DB {
	
    private $dblink; // the anyDB link 
    
    /**
     * constructs a new DB object
     */
    function __construct()
    {
    	switch($GLOBALS['DB_type'])
    	{
    		case 'MYSQL':
    			$this->connect_toMySql();
    			break;
    		case 'SQLITE':
    			$this->connect_toSQLite();
    			break;
    	} 
    	
    } // constructor
    
    /**
     * destructs the DB object, freeing up all resources
     */
    
    function __destruct() 
    {
    	$this->dblink->free();
		$this->dblink->disconnect(); 
    } // destructor
    
    
    /**
	  * Submits an sql statement to the db
	  * @access   public
	  * @param    String      $query
	  * @return   Boolean     TRUE, if successful
	  */
    public function query($query)
    {
    	return $this->dblink->query($query);	
    }
    
	/**
	 * Returns the resulting table in an 2-dimensional array
	 * @access   public
	 *
	 * @param    Integer     $resultType         should the array have numeric, associative keys, or both
	 *
	 * @return   Mixed       2-dimensional array
	 */
	function getAll($resultType = ANYDB_PREDEFINED_VALUE)
	{
		return $this->dblink->getAll($resultType);
	}    
    
	/**
	* Executes a statement and returns the result table
	*
	* @abstract 
	* @access   public
	*
	* @param    String      $query              a sql statement
	* @param    Integer     $resultType         should the array have numeric, associative keys, or both
	*
	* @return   Mixed       2-dimensional array or FALSE
	*/
	function execute($query, $resultType = ANYDB_PREDEFINED_VALUE) 
	{
		return $this->dblink->execute($query, $resultType);	
	}    
    
	/**
	* Returns the next row in an array
	*
	* @abstract 
	* @access   public
	*
	* @param    Integer     $resultType         should the array have numeric, associative keys, or both
	*
	* @return   Mixed       1-dimensional array or FALSE
	*/
    public function getNext($resultType = ANYDB_PREDEFINED_VALUE)
    {
    	return $this->dblink->getNext($resultType);	
    }
    
    private function connect_toMySql()
    {
		$this->dblink = anyDB::getLayer('MYSQL','', 'mysql');
		/* Connecting, selecting database */
		$this->dblink->connect($GLOBALS['DB_host'], $GLOBALS['DB_DB'], $GLOBALS['DB_un'], $GLOBALS['DB_pw']); 
		
    } // connect_toMySql()
    
    private function connect_toSQLite()
    {
    	$this->dblink = anyDB::getLayer('SQLITE', '', 'sqlite');
    	/* Connecting, selecting database */
    	$this->dblink->connect($GLOBALS['DB_host'], $GLOBALS['DB_SQLITE_DBPATH'].$GLOBALS['DB_DB'], $GLOBALS['DB_un'], $GLOBALS['DB_pw'] ); 	
    }

	/**
	* Modifies a string to make it secure to add to the db
	*
	* @abstract 
	* @access   public
	*
	* @param    Mixed       $str        a string or an array
	* @param    Array       $keys       if not null it specifies which key names to use
	*
	* @return   Mixed       String or FALSE
	*/
	public function escapeStr($str, $keys = null) 
	{
		return $this->dblink->escapeStr($str, $keys);
	}

	
	/**
	* Returns the id of the last insert operation
	*
	* @access   public
	*
	* @return   Mixed   int or FALSE
	*/
	public function getInsertId() 
	{
		return $this->dblink->getInsertId();	
	}
    
    /**
	* Returns how many rows are in the result set
	*
	* @abstract 
	* @access   public
	*
	* @return   Mixed       TRUE, if successful
	*/
    public function numRows()
    {
    	return $this->dblink->numRows();	
    } 
	
	/**
	* Returns how many rows were affected by the last statement
	*
	* @abstract 
	* @access   public
	*
	* @return   Mixed       Integer or FALSE
	*/	
	public function affectedRows()
	{
		return $this->dblink->affectedRows();
	}
    
	public function getGoodDBURLName( $thisname)
	{
		$thisname = urldecode( $thisname); 
		// case insensitive
		$thisname = strtolower( $thisname); 
		// make these chars into spaces
		$search = array(" ", "+", "-");
		$thisname = str_replace( $search, " ", $thisname);
		Return $thisname;
	}
}
?>