<?php
////////////////////////////////////////////////////////////////////////
/**
 *	functions.inc - helper functions used throughout the system			
 *						  
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////

/**
 * returns a Globally Unique Identifier string.
 * note: these GUIDs are not compatible with Microsoft's GUIDs
 * 
 * @return string a unique identified string.
 */
function CreateGUID()
{
	srand( ( double)microtime( ) * 1000000);
	$r = rand();
	$u = uniqid( getmypid( ) . $r . ( double)microtime( ) * 1000000, 1);
	$m = md5($u);
	return( $m);
} 


/**
 * removes the file extension and query string from a given pathstring.
 * 
 * @param string $pathname the requested file path with extension and query string
 * @return string the origional path+filename without 
 */
function removeFileExtension( $pathname)
{
	$parts = split( "[/]", $pathname);
	$FNparts = split( "[?&]", $parts[count( $parts)-1]);
	$filename = $FNparts[0];
	$fparts = split( "[.]", $filename);
	$extension = "." . $fparts[count( $fparts)-1]; 
	// echo("fn = ".$filename." ext=".$extension."<br>");
	$file_base = str_replace( $extension, "", $filename);
	Return $file_base;
} 


/**
 * outputs an HTTP error message, with its associated HTTP header
 * 
 * @todo a 404 not found error could redirect to a special "not found handler" template.
 */
function OutputError( $errnum)
{
	switch ( $errnum) {
		case "404": header("HTTP/1.0 404 Not Found"); echo( "<h1>404 - Page or Folder not found in database</h1>"); break;
		case "500":	header("HTTP/1.0 500 Internal Server Error"); echo( "<h1>500 - Invalid Configuration</h1>"); break;
		case "601": echo( "<h1>Error 601: no currentPipeline found</h1>"); break;
	} // switch
} 

/**
 * returns an initialized pipeline object with a given pipeline name
 * 
 * @param string @pipelinename the pipeline class to load
 * @param Context $context the current context object
 * @return pipelineBase An initialized Pipeline object, or NULL if the pipeline is not found
 */
function LoadPipeline( $pipelinename, $context)
{

	$incFN = $GLOBALS['pipeline_dir'] . $pipelinename . ".inc";
	if ( !file_exists( $incFN)) {
		echo("LoadPipeline not found: ".$pipelinename);
					return null;
	} 
	include_once( $incFN);
	
	$eval_ret = eval( "\$obj = new \$pipelinename(\$context);");
	if ($eval_ret === FALSE)
	{
		// eval returns FALSE if there was some error evaluating the code
		return NULL;
	}
	return $obj; 
} // LoadPipeline

/**
 * tests to see if an object is a page object
 * 
 * @return bool TRUE if the object is a Page object, FALSE if not.
 */
function is_Page($object) 
{
	Return (get_class($object) == 'Page' );
}

/**
 * outputs an object's internals, then dies.
 */
function debug($obj) 
{
		echo("<pre>");
		print_r($obj);
		echo("</pre>");	
		die();
}

/**
 * The recursive part of ListOfTemplatesToHTML and ListOfPipelinesToHTML
 * @access private
 */
function _addFolderToSelect($_folder, $_baseFolder, $_selVal) 
{
	# echo("xxx".$_folder); 
	$h = "";
	if ($handle = opendir($_folder)) 
	{
		/* This is the correct way to loop over the directory. */
		while (false !== ($file = readdir($handle))) 
		{ 
			$f = $_folder.$file;
			if($_folder[strlen($_folder)-1] != "/") 
			{
				$f = $_folder."/".$file;
			}

			if ($file != "." && $file != ".." && ! strEndsWith($file,'.class.inc') && ! strEndsWith($file,'.bak') && !is_dir($_folder."/".$file)) 
			{
				$folder_name = relativePath($_baseFolder, $f);
				
				$template_name = str_replace(".inc/","",$folder_name);
				$seltxt = "";
				if (strcasecmp($_selVal, $template_name) == 0){ $seltxt = " selected"; }
					// select

				$h = $h."<option value=\"".$template_name."\" ".$seltxt.">".$template_name."</option>\n";
			}
			elseif($file != "." && $file != ".." && ! strEndsWith($file,'.class.inc') && ! strEndsWith($file,'.bak') && is_dir($_folder."/".$file))
			{
				// recursive
				$h = $h._addFolderToSelect($f, $_baseFolder, $_selVal);
			}

		}
	}
	return $h;
		
}

/**
 * Returns an HTML string containing a SELECT control populated with the available templates
 * 
 * @return string the HTML string containing the available templates
 * @todo move this to a Control
 */
function ListOfTemplatesToHTML($_name, $_selVal) 
{

	$h = "<select name=\"".$_name."\">\n";

	$h = $h."<option value=\"\">[ inherit from parent ]</option>";
	$h = $h._addFolderToSelect($GLOBALS['template_dir'], $GLOBALS['template_dir'], $_selVal);
	$h = $h."</select>";
	return $h;
	
}

/**
 * Returns an HTML string containing a SELECT control populated with the available Pipelines
 * 
 * @return string the HTML string containing the available Pipelines
 * @todo move this to a Control
 */
function ListOfPipelinesToHTML($_name, $_selVal) 
{

	$h = "<select name=\"".$_name."\">\n";

	$h = $h."<option value=\"\">[ inherit from parent ]</option>";
	$h = $h._addFolderToSelect($GLOBALS['pipeline_dir'], $GLOBALS['pipeline_dir'], $_selVal);
	$h = $h."</select>";
	return $h;
	
}

/**
 * Tests if returns a boolean true if str ends with ending (case insensitive)
 * @param string $str the string to search
 * @param string $ending the ending to search for in $str
 * @return bool TRUE if $str ends with $ending
 */
function strEndsWith($str, $ending) 
{
	if(strlen($str) < strlen($ending)) 
	{
		return false;		
	}
	$end = substr($str,strlen($str)-strlen($ending));
	return (strcasecmp($ending, $end)==0);
	
} // strEndsWith

/**
* Return the relative path between two paths / Retourne le chemin relatif entre 2 chemins
*
* If $path2 is empty, get the current directory (getcwd).
* @return string
*/
function relativePath($path1, $path2='')
{
	if ($path2 == '') {
		$path2 = $path1;
		$path1 = getcwd();
	}
	//Remove starting, ending, and double / in paths
	$path1 = trim($path1,'/');
	$path2 = trim($path2,'/');
	while (substr_count($path1, '//')) $path1 = str_replace('//', '/', $path1);
	while (substr_count($path2, '//')) $path2 = str_replace('//', '/', $path2);
	//create arrays
	$arr1 = explode('/', $path1);
	if ($arr1 == array('')) $arr1 = array();
	$arr2 = explode('/', $path2);
	if ($arr2 == array('')) $arr2 = array();
	$size1 = count($arr1);
	$size2 = count($arr2);
	//now the hard part :-p
	$path='';
	for($i=0; $i<min($size1,$size2); $i++)
	{
		if ($arr1[$i] == $arr2[$i]) continue;
		else $path = '../'.$path.$arr2[$i].'/';
	}
	if ($size1 > $size2)
		for ($i = $size2; $i < $size1; $i++)
			$path = '../'.$path;
	else if ($size2 > $size1)
		for ($i = $size1; $i < $size2; $i++)
			$path .= $arr2[$i].'/';

	return $path;
}

/**
 * outputs the mime header for a given requested. The $_req must have a filename extension to find the filetype.
 * 
 * @param string $_req the requested path+file (with the path levels delimited using '/'). Does not work with a query string.
 * 
 * @return bool TRUE if the header was sent, FALSE if not.
 */
function OutputMimeHeader($_req)
{
	$h = "";
	// -- get the filename extension by first getting the requested filename 
	$parts = explode("/",$_req);	
	// $parts[count($parts)-1] now has the requested filename
	$ext_parts = explode(".",$parts[count($parts)-1]);
	// $ext_parts[count($ext_parts)-1] now has the extension. All other parts of $ext_parts are the filename
	$ext = strtolower($ext_parts[count($ext_parts)-1]);

	// lookup the mime type (based on http://www.w3schools.com/media/media_mimeref.asp)
	// note: could use "mime_content_type", except that requires custom install on Win32
	switch($ext)
	{
		case 'jpeg':
		case 'jpe':
		case 'jpg':
			$h = 'image/jpeg';
			break;
		case 'gif':
			$h = 'image/gif';
			break;
		case 'pdf':
			$h = 'application/pdf';
			break;
		case 'js':
			$h = 'application/x-javascript';
			break;
		case 'ico':
			$h = 'image/x-icon';
			break;
		case 'css':
			$h = 'text/css';
			break;
		case 'txt':
			$h = 'text/plain';
			break;
		default:
			$h = 'text/html';
	} // switch
	
	if($h != "" && ! headers_sent()) 
	{
		header('Content-type: '.$h);
		return TRUE;
	}
	else
	{
		return FALSE;	
	}

} // OutputMimeHeader

/**
 * tests to see if a variable is set in the $_REQUEST variable, and that it is not blank
 * 
 * @return bool TRUE if the variable exists and is not blank, FALSE otherwise
 */
function req_isSet($req_name) 
{
	if(isset($_REQUEST[$req_name]) && $_REQUEST[$req_name] != "" ) 
	{
		return true;		
	}
	return false;	
}

/**
 * gets a usable URL that is in the configuration file. This allows 'use_clean_urls' to be used
 * 
 * @param string $name the configuration variable name 
 * @param bool $args an associative array of parameters to add to the URL
 * 
 * @return string the URL, taking use_clean_urls into account, and $args into account. '' on error.
 */
function get_config_url($name, $args = false)
{
	if(isset($GLOBALS[$name]))
	{
		if(!$GLOBALS['use_clean_urls'])
		{
			$params = '';
			if($args !== FALSE)
			{
				foreach ($args as $key => $value)
				{
					$params = $params."&$key=$value";	
				}	
			}
			return $GLOBALS['non_clean_url_base'].$GLOBALS[$name].$params;	
		}
		else
		{
			$params = '';
			if($args !== FALSE)
			{
				$prefix = '?';
				foreach ($args as $key => $value)
				{
					$params = $params."$prefix$key=$value";
					$prefix = '&';	
				}	
			}
			return $GLOBALS[$name].$params;	
 	
		}
	}
	else
	{
		return '';
	}	
} // get_config_url

?>
