<?php 
include_once("functions.inc");
include_once("PagePart.class.inc");
////////////////////////////////////////////////////////////////////////
/**
 * 	
 *A Page object defines everything that is a Page on the website 
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////
class Page 
{ 	

	/**
	 * @var string the URL name (ie the filename)
	 */
	public $name; // the url name
	/**
	 * @var string the human readable title
	 */
	public $displayname;
	/**
	 * @var int the sort position of this item
	 */
	public $sortordinal; 
	/**
	 * @var string the Page ID for this page
	 */
	public $GUID;		// string
	/**
	 * @var pipelineBase the pipeline object associated with this page
	 */
	public $pipeline; // object
	/**
	 * @var string the name of the pipeline associated with this page
	 */
	public $pipeline_name; // string

	/**
	 * @var array array of PagePart objects that belong to this page.
	 */
	public $pageParts;	
	/**
	 * @var Context the current context
	 */
	public $context;
	/**
	 * @var string the name of the current template
	 */
	public $templateName;
	
	/**
	 * @var int the PageGUID of the parent page
	 */
	public $parentPageID; // integer

	/**
	 * @var array an array containing the list of subPages (used only in $this->subPagesCache())
	 */
	private $subPagesCache; // array
	
	/**
	 * @var bool TRUE if subPagesCache has been initialized, FALSE if not. 
	 */
	private $subPages_useCache; // boolean
   
	/**
	 * creates a new Page object
	 * @param Context $_context The current context object
	 */
	public function Page(Context $_context)
	{
		$this->GUID = -1;
		$this->sortordinal = -1;
		$this->name = "";
		$this->displayname = "";

		$this->pageParts = array();
		$this->context = $_context;
		$this->pipeline = null;

		$this->templateName = "";
		$this->parentPageID = -1;

		$this->subPages_useCache = false;
		$this->subPagesCache = array();

	} // constructor

	public function InitFromDatabase($_parentPageID, $_name )
	{
		$this->parentPageID = $_parentPageID;
				
		$_name = $this->context->db->getGoodDBURLName($_name);
		$parentQuery = "and parentPage = ".$_parentPageID."";
		if($_parentPageID == "" || $_parentPageID === "-1" || $_parentPageID ===-1 || $_parentPageID == 'null' || $_parentPageID == "NULL") 
		{
			$parentQuery = "and isNull(ParentPage)";
		}
		$sql = "SELECT `PagesIndex`, `templateName`, `pipeline`, `Name`, `DisplayName`, `ParentPage`, `SortOrdinal` FROM `Pages` where (now() < Deleted or IsNull(Deleted)) ".$parentQuery." and (Name = '".$_name."')"; 

		// do the query
		$result = $this->context->db->query($sql);
				 
		if($this->context->db->numRows() > 0  ) 
		{
			// get the data row
			$row = $this->context->db->getNext();
			
			$this->loadFromDBRow($row);
			$this->InitPageParts();
			return true;

		}
		else
		{
			return false;
		}
	}


	/**
	 * Initializes this page from the database based on the page's GUID
	 * 
	 * @param int $_pageID the unique identifier for the page to load
	 * @return bool returns TRUE if initialized successfully, FALSE if not
	 */
	public function InitFromDatabaseByID($_pageID )
	{

		$sql = "SELECT `PagesIndex`, `templateName`, `pipeline`, `Name`, `DisplayName`, `ParentPage`, `SortOrdinal` FROM `Pages` where (now() < Deleted or IsNull(Deleted)) and (`PagesIndex` = '".$_pageID."')"; 

		// do the query
		$result = $this->context->db->query($sql);
				 
		if($this->context->db->numRows() > 0  ) 
		{
			// get the data row
			$row = $this->context->db->getNext();

			$this->loadFromDBRow($row);

			$this->InitPageParts();

			return true;

		}
		else
		{
			return false;
		}
	}


	public function loadFromDBRow($row) 
	{
		$this->GUID = $row["PagesIndex"];
		$this->parentPageID = $row["ParentPage"];

		$this->name = $row["Name"];
		$this->displayname = $row["DisplayName"];
		$this->sortordinal = $row["SortOrdinal"];

		$this->templateName = $row["templateName"];
		
		if($row["pipeline"] != NULL && $row["pipeline"] != "")
		{
			$this->pipeline_name = $row["pipeline"];
			$this->pipeline = LoadPipeline($row["pipeline"], $this->context);
		}

	} // loadFromDBRow


	
	/**
	 * Loads up the PageParts associated with this page.
	 * 
	 * @return bool returns TRUE if all PageParts loaded successfully, FALSE for any errors.
	 */
	public function InitPageParts()
	{
	 	
		// echo("initPageParts()<br>");
		$sql = 'SELECT `GUID`, `parentPage`, `name`, `type`, `sortOrdinal`, `Deleted` FROM `pageparts` WHERE (now() < Deleted or isnull(deleted)) and parentPage='.$this->GUID." ORDER BY sortOrdinal";

		// do the query
		$result = $this->context->db->query($sql);
				 
		if($this->context->db->numRows() > 0  ) 
		{
			// get the data row
			$row = $this->context->db->getNext();
			while ($row !== FALSE)
			{
    			// (Page $_parentPage, $_type, $_name, $_GUID)
				$p = new pagePart($this,$row["type"],$row["name"],$row["GUID"],$row["sortOrdinal"],$this->context);
				
				array_push($this->pageParts, $p);
				$row = $this->context->db->getNext();
			}
			return true;
		}
		else
		{
		 	return false;
		}
	
	} // InitPageParts	

	/**
	 * gets the URL for this page
	 * 
	 * @return string the URL for this page
	 */
	public function URL($asFolder = true)
	{

		$url = '';
		$parentPage = $this->parentPage();

		while($parentPage != NULL) 
		{
			$url = $parentPage->name."/".$url;

			$parentPage = $parentPage->parentPage();				
		} // while

		$url = $url.$this->name;
		
		if($url == "") 
		{
			$url = "/";		
		}
		
		if(!$GLOBALS['use_clean_urls'])
		{
			$url = $GLOBALS['non_clean_url_base'].$url;	
		}

		return $url;		
		
	} // URL

	/**
	 * gets the parent page of this current page. 
	 * @return Page returns the parent page, or NULL if none exists.
	 */
	public function parentPage() 
	{
		$ret = NULL;
		if($this->parentPageID != -1 && $this->parentPageID != "") 
		{
			# echo('parentpage '.$this->parentPageID);
			$ret = $this->context->getPageByPageID($this->parentPageID);	
			# echo('xx');
		}
		return $ret;
	} // parentPage

	
	/**
	 * Executes (ie displays) the current Page
	 */
	public function Execute()
	{
		
		if (!$this->context->isValid) {
			return;    
		}

		$template = new TemplateExecuter($this->context, $this->templateName,$this->pageParts);
		
		$template->execute();

	} // execute


	/**
	 * Saves the current Page's data to the database by either inserting it, or updating it
	 * note: the Page's GUID must be set and valid
	 */
	public function SaveToDatabase() 
	{	
		$_guid = $this->GUID;

		$sql = "SELECT `PagesIndex` FROM `Pages` where (now() < Deleted or IsNull(Deleted)) and (PagesIndex = '".$_guid."')"; 

		// do the query
		$result = $this->context->db->query($sql);
				 
		if($this->context->db->numRows() > 0  ) 
		{
			// get the data row
			$row = $this->context->db->getNext();
			// ----------------
			// -- the page exists in the database. let's update it
			$return = $this->UpdateDatabase($row["PagesIndex"]);
		}
		else
		{
			// ----------------
			// -- page does not exist. let's create it
			$return = $this->InsertIntoDatabase();
		}
		
		return $return;

		
	} // SaveToDatabase

	private function UpdateDatabase($PageGuid) 
	{
		$pipeline_name = $this->pipeline_name;
		
		$sql = "UPDATE Pages SET ParentPage = ".$this->parentPageID.", Name = '".$this->name."', DisplayName = '".$this->displayname."', SortOrdinal = '".$this->sortordinal."', templateName = '".$this->templateName."', pipeline = '".$pipeline_name."' where PagesIndex = '".$PageGuid."';";

		// do the query
		$result = $this->context->db->query($sql);
				 
		return ($this->context->db->affectedRows() == 1);
		
	} // UpdateDatabase

	private function InsertIntoDatabase($link) 
	{

		$sql = "INSERT INTO Pages (ParentPage, Name, DisplayName, SortOrdinal, templateName, pipeline) VALUES(".$this->parentPageID.", '".$this->name."', '".$this->displayname."','".$this->sortordinal."', '".$this->templateName."','".$this->pipeline_name."');";

		// do the query
		$result = $this->context->db->query($sql);

		$id = $this->context->db->getInsertId();
		if($id == 0) { $this->GUID = -1; return false;}
		else 
		{
			 $this->GUID = $id;
			 return true;
		}
		
	} // InsertIntoDatabase
	
	/**
	 * Returns an array of Page objects that are children to the current Page
	 */
	public function subPages()
	{

		if($this->subPages_useCache) 
		{
			return $this->subPagesCache;
		}

		$ret = array();

		$_parentPageID = $this->GUID;
		$parentQuery = "and parentPage = ".$_parentPageID."";
		if($_parentPageID == "" || $_parentPageID === "-1" || $_parentPageID ===-1 || $_parentPageID == 'null' || $_parentPageID == "NULL") 
		{
			$parentQuery = "and isNull(ParentPage)";
		}
		
		$sql = "SELECT `PagesIndex` FROM `Pages` where (now() < Deleted or IsNull(Deleted)) ".$parentQuery; 
		$return = false;
		// do the query
		$result = $this->context->db->query($sql);
				 
		if($this->context->db->numRows() > 0  ) 
		{
			// get all the data rows
			$rows = $this->context->db->getAll();
			foreach($rows as $row)
			{								
				$page = $this->context->getPageByPageID($row['PagesIndex']);
				if($page != null) 
				{
					$ret[$page->GUID] = $page;
					# echo("subpages->(".$page->GUID.")<br>");
				}
				else
				{
					echo("<br>bad Page Index: ");
					debug($row);
				}
				// $row = $this->context->db->getNext();
			} // while
		}
		if(count($ret)> 0) 
		{
			$this->subPages_useCache = true;
			$this->subPagesCache = $ret;
			
		}
		# echo("subpages:".mysql_num_rows($result));
		# debug($ret);
		return $ret;
		
	} // subPages

	public function attachments()
	{

		$ret = array();

		$_parentPageID = $this->GUID;
		$parentQuery = "and parentPage = ".$_parentPageID."";
		if($_parentPageID == "" || $_parentPageID === "-1" || $_parentPageID ===-1 || $_parentPageID == 'null' || $_parentPageID == "NULL") 
		{
			$parentQuery = "and isNull(ParentPage)";
		}
		
		$sql = "SELECT `attachmentId` FROM `Attachments` where (now() < Deleted or IsNull(Deleted)) ".$parentQuery; 
		
		/* Performing SQL query */ 
		$result = $this->context->db->query($sql); 
		if($this->context->db->numRows() > 0)
		{		
			$rows = $this->context->db->getAll();
			foreach($rows as $row)
			{								
				$attach = $this->context->getAttachmentByAttachmentID($row['attachmentId']);
				if($attach != null) 
				{
					# debug($attach);
					$ret[$attach->attachment_id] = $attach;
					# echo("subpages->(".$page->GUID.")<br>");
				}
				else
				{
					echo("<br>bad Attachment Index: ");
					debug($row);
				}

			} // while
		}
		if($result) 
		{
			# $this->subPages_useCache = true;
			# $this->subPagesCache = $ret;
			
		}
		# echo("subpages:".mysql_num_rows($result));
		# debug($ret);
		return $ret;
		
	} // attachments


} 
?>
