<?php
////////////////////////////////////////////////////////////////////////
/**
 *	An abstract class that defines the functions needed for child pipeline classes.
 *
 * Pipelines are used by the Pomo Website Management System to handle the storage and retrieval
 * of PagePart data.
 * 
 * Examples of possible Pipelines include: 
 * 	- Publishing data immediately (the simplest case, implemented in PublishImmediately.inc)
 * 	- Publish data only after approval
 * 	- Publish data only after several approval steps
 * 	- Publish data of only the current revision 
 * 
 * Each page can have a Pipeline associated with it, or will inherit it from a parent page. This
 * allows for different sections of your site to have different processing rules.
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////

abstract class pipelineBase
{   
	public $context;
	
	/**
	 * Create the Pipeline Object
	 */
	function __construct(Context $_context)
	{
		$this->context = $_context;
	}

   /**
    * adds an object to the pipeline, and stores it.
    * 
    * @param string $_guid The GUID of the PagePart we are submitting data for 
    * @param Mixed $_data The data to serialize and store in the pipeline
    * 
    * @return bool TRUE if submitted and stored, FALSE otherwise
    */
   abstract public function submitToStart($_guid, $_data);
   
   /**
    * process all items in the pipeline. Moves items to the next stage of the Pipeline if they are ready.
    * 
    * This function is not currently implemented or well defined.
    */
   abstract public function processPipeline();
   // getStatus:
   // 
   /**
    * gets an associative array with data describing the status of a PagePart inside of the Pipeline
    * 
    * @param string $GUID the GUID of the PagePart that data is requested for.
    * 
    * @return array returns an array: array(["status"]=> 'Pending'|'Published'; ["description"]=> 'extended description of status')
    */
   abstract public function getStatus($GUID);
   
   /**
    * gets the data for a PagePart, no matter where it is in the Pipeline processing
    * 
    * @param string $GUID the GUID of the PagePart that data is requested for.
    * 
    * @return mixed the data associated with the PagePart, or NULL on error
    */
   abstract public function getObjectInPipeline($GUID);
   
}
?>