<?php
////////////////////////////////////////////////////////////////////////
/**
 *	install.php - This file will install the PoMo Website Management System to the hosted machine
 *
 * @link        http://pomo.sourceforge.net for the latest version
 * @author	    Jason Suwala <jsuwala[at]gmail.com>
 * @copyright	Jason Suwala <jsuwala[at]gmail.com> - distributed under the GPL
 * 
 * @package Pomo_Website_Management_System
 * @version 0.1
 * @license http://www.opensource.org/licenses/gpl-license.php General Public License (GPL)
 * 
 */
////////////////////////////////////////////////////////////////////////
function install_todo()
{
	/**
	 * @todo finish of the install script, making sure that it works with many different databases
	 * @todo add check for proper file/directory permissions
	 */
}
include_once('../core/config.inc');
include_once('../core/db.class.inc');

function outputInstall_Errorbox($message)
{
	echo('<div style="width:200px; align:center; border: 1px solid red; text-align: center; background-color: #EECCCC;">' .
		'<strong>Error:</strong><br>' . $message .
		'</div>');
} // install_errorbox

function check_modrewriteEnabled()
{
	if (strtolower($_SERVER['PHP_SELF']) != '/install/install.php')
	{
		outputInstall_Errorbox('You must access this page without mod_rewrite enabled!<p>Edit the .htaccess file, and set "RewriteEngine" to "Off"');
		die();	
	}
	else
	{
		echo('Checking if mod_rewrite is disabled for installation...<br>PASSED<p>');	
	}
}

function checkPHPVersion()
{
	$current_version = phpversion();
	$required_version = "5.0.0";
	
	if(version_compare($current_version, $required_version) <= 0)
	{
		outputInstall_Errorbox('The version of PHP you are running is not compatible with the PoMo Website Management System. You must use PHP version '.$required_version.' or greater. (you are currently running PHP version '.$current_version.')');
		die();		
	}	
	else
	{
		echo('Checking the version of PHP...<br>PASSED<p>');		
	}
}

function checkRootCorePathConfig()
{
	$error = true;
	if (isset($GLOBALS['root_core_path']))
	{
		$path = $GLOBALS['root_core_path'];
		if (file_exists($path.'Context.class.inc'))
			$error = false;
	}
	if ($error)
	{
		outputInstall_Errorbox('The configuration option "root_core_path" must be set to the directory of the PoMo Website Management System\'s CORE directory.');		
	}
	else
	{
		echo('Checking that the root core path name has been set...<br>PASSED<p>');
	}
} // checkRootCorePathConfig

function outputDatabaseConfig()
{
	echo('Your system will be setup with the following database configuration: <ul>' .
			'<li>type: '.$GLOBALS['DB_type'].'<br>' .
			'<li>host: '.$GLOBALS['DB_host'].'<br>' .
			'<li>name: '.$GLOBALS['DB_DB'].'<br>'.
			'<li>username: '.$GLOBALS['DB_un'].'<br>' .
			'<li>password:'.$GLOBALS['DB_pw'].'</ul>'			
			);	
}

function createDatabaseTables()
{
	$db = new DB();
	
	$sql_createPages = "CREATE TABLE pages (
						  PagesIndex int(11) NOT NULL auto_increment,
						  Name varchar(50) NOT NULL default '',
						  DisplayName varchar(255) NOT NULL default '',
						  ParentPage int(11) default '0',
						  SortOrdinal int(11) NOT NULL default '0',
						  pipeline varchar(255) default NULL,
						  templateName varchar(255) NOT NULL default '',
						  Deleted date default NULL,
						  PRIMARY KEY  (PagesIndex)						  
						); ";
						
	$sql_createUsers = "CREATE TABLE users (
						  UserIndex int(11) NOT NULL default '0',
						  username varchar(255) NOT NULL default '',
						  password varchar(255) NOT NULL default '',
						  accesslevel int(11) NOT NULL default '0',
						  email varchar(255) NOT NULL default '',
						  Deleted datetime default NULL,
						  PRIMARY KEY  (UserIndex),
						  UNIQUE KEY username (username)
						);";
	$r = $db->query($sql_createPages);
	echo($sql_createPages);
	echo('<p>result =>');
	print_r($r);
	echo('<=');	
}

function outputNextStepLink($currentStep)
{
	$nextStep = $currentStep+1;
	echo('If all this looks fine, <a href="install.php?step='.$nextStep.'">click here to proceed</a>');
}

function outputStepHeader($step)
{
	echo ('<html><head><style>body { font-family: verdana, arial; }</style>' .
			'</head><body><strong>PoMo Website Management System Installation - Step '.$step.'</strong><p>');	
} // outputStepHeader

function outputStepFooter($step)
{
	echo('</body></html>');	
}

$step = 1;
if (isset($_REQUEST['step']) && is_numeric($_REQUEST['step']))
{
	$step = $_REQUEST['step'];	
}

outputStepHeader($step);
switch ($step)
{
	case 1:
		checkPHPVersion();
		check_modrewriteEnabled();
		checkRootCorePathConfig();	
		outputDatabaseConfig();
		outputNextStepLink($step);
		break;
	case 2:
		CreateDatabaseTables();
		break;
}
outputStepFooter($step);


?>
